;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "mgmtconfig-mode" "20251028.2100"
  "Mgmt configuration management language."
  '((emacs "24.3"))
  :url "https://github.com/purpleidea/mgmt/misc/emacs"
  :commit "7079121217a345c45a31f4f75f6f3b1c0d92a84e"
  :revdesc "7079121217a3"
  :keywords '("languages")
  :authors '(("Peter Oliver" . "mgmtconfig@mavit.org.uk"))
  :maintainers '(("Mgmt contributors" . "https://github.com/purpleidea/mgmt")))
